@@ -22,8 +22,10 @@ def gnssir_guts(station,year,doy, snr_type, extension,lsp):
     Parameters
     ----------
     station : string
+        4 character station name
 
     year : integer
+        full year
 
     doy : integer
         day of year
@@ -32,6 +34,7 @@ def gnssir_guts(station,year,doy, snr_type, extension,lsp):
         snr file type
 
     extension : string
+        optional subdirectory to save results
 
     lsp : dictionary
         REQUIRES DESCRIPTION
@@ -52,6 +55,7 @@ def gnssir_guts(station,year,doy, snr_type, extension,lsp):
         dec = lsp['dec']
     else:
         dec = 1 # so Jupyter notebooks do not need to be rewritten
+    print('Decimate:', dec)
     #print('Number of azimuths', len(azval))
     for i in range(0,len(azval),2):
         #print(i, azval[i], azval[i+1])
@@ -281,15 +285,14 @@ def local_update_plot(x,y,px,pz,ax1, ax2,failure):
 
 def plot2screen(station, f,ax1,ax2,pltname):
     """
-    Add axis information and Send the plot to the screen
+    Add axis information and Send the plot to the screen.
+    https://www.semicolonworld.com/question/57658/matplotlib-adding-an-axes-using-the-same-arguments-as-a-previous-axes
 
     Parameters
     ----------
     station : string
         4 character station ID
 
-    https://www.semicolonworld.com/question/57658/matplotlib-adding-an-axes-using-the-same-arguments-as-a-previous-axes
-
     """
     ax2.set_xlabel('Reflector Height (m)'); 
     #ax2.set_title('SNR periodogram')
@@ -310,26 +313,28 @@ def read_json_file(station, extension):
 
     Parameters
     ----------
-    station : string
+    station : str
         4 character station name
 
-    extension : string
-        experimental directory - default is ''
+    extension : str
+        experimental subdirectory - default is ''
 
     Returns
     -------
     lsp : dictionary
 
     """
-    lsp = {} # ???
+    lsp = {} # 
     instructions_ext = str(os.environ['REFL_CODE']) + '/input/' + station + '.' + extension + '.json'
     instructions = str(os.environ['REFL_CODE']) + '/input/' + station + '.json'
     if os.path.isfile(instructions_ext):
+        usefile = instructions_ext
         #print('using specific instructions for this extension')
         with open(instructions_ext) as f:
             lsp = json.load(f)
     else:
         #print('will use the default instruction file')
+        usefile = instructions
         if os.path.isfile(instructions):
             with open(instructions) as f:
                 lsp = json.load(f)
@@ -338,6 +343,13 @@ def read_json_file(station, extension):
             print('Please make with make_json_input and run this code again.')
             sys.exit()
 
+    if len(lsp['reqAmp']) < len(lsp['freqs']) :
+        print('Number of frequencies found in json: ', len(lsp['freqs']))
+        print('Number of required amplitudes found in json: ', len(lsp['reqAmp']))
+        print('You need to have a required Amplitude for each frequency.')
+        print('Please fix your json file: ', usefile)
+        sys.exit()
+
     return lsp
 
 
