@@ -19,10 +19,12 @@ import gnssrefl.rinex2snr as rinex
 
 def read_snr_simple(obsfile):
     """
+    Loads the data from a SNR file into memory 
+
     Parameters
     ----------
     obsfile : string
-        name of SNR file
+        name of the SNR file
 
     Returns
     -------
@@ -111,68 +113,51 @@ def read_snr_simple(obsfile):
 
 def quickLook_function(station, year, doy, snr_type,f,e1,e2,minH,maxH,reqAmp,pele,satsel,PkNoise,fortran,pltscreen,azim1,azim2,ediff,**kwargs):
     """
+    takes in all users inputs and calculates reflector heights. Makes png files.
 
     Parameters
     ----------
     station : str
-        name (4 char) 
-
+        station name (4 char) 
     year : int
         full year
-
     doy : int
         day of year  
-
     snr_type : int
         snr file extension (i.e. 99, 66 etc)
-
     f : int
         frequency (1, 2, 5), etc
     e1 : float
         minimum elevation angle in degrees
-
     e2 : float
         maximum elevation angle in degrees
-
     minH : float
         minimum allowed reflector height in meters
-
     maxH : float
         maximum allowed reflector height in meters
-
     reqAmp : float
         is LSP amplitude significance criterion
-
     pele : list of floats
         is the elevation angle limits for the polynomial removal.  units: degrees
-
     satsel : int
         satellite number?
-
     PkNoise : float
         peak to noise ratio for QC
-
     fortran : bool
          whether external fortran translator is being explicitly called. 
-
     pltscreen : bool
-        whether you want plots to the screen
-
+        whether you want plots sent to the terminal
     azim1 : float
          minimum azimuth in degrees
-
     azim2 : float
          maximum azimuth in degrees
-
     ediff : float
-         QC parameter - restricts length of arcs
-         degrees
-
-    Returns
-    -------
-
+         QC parameter - restricts length of arcs (degrees)
 
     """
+
+    print('ediff',ediff)
+
     screenstats = kwargs.get('screenstats',False)
     if screenstats:
         print('Some screen statistics will print to the screen')
@@ -206,12 +191,11 @@ def quickLook_function(station, year, doy, snr_type,f,e1,e2,minH,maxH,reqAmp,pel
     #  fontsize
     fs = 10
     # various defaults - ones the user doesn't change in this quick Look code
-    delTmax = 70
+    # changed this december 4, 2022
+    # changed it back on december 20, 2022
+    delTmax = 75 # this is how long an arc can be in minutes
     polyV = 4 # polynomial order for the direct signal
-    desiredP = 0.01 # 1 cm precision
-
-
-    #ediff = 2 # this is a QC value, now explicitly sent from command line code
+    desiredP = 0.01 # 1 cm precision for a "quick Look"
 
     #four_in_one = True # put the plots together
     minNumPts = 20 
@@ -332,7 +316,7 @@ def quickLook_function(station, year, doy, snr_type,f,e1,e2,minH,maxH,reqAmp,pel
                                 plt.plot(px,pz,'gray',linewidth=0.5)
                             if screenstats:
                                 print('FAILED QC for Azimuth {0:5.1f} Satellite {1:2.0f} UTC {2:5.2f} RH {3:7.3f} '.format( avgAzim,satNu,UTCtime,maxF))
-                                g.write_QC_fails(delT,75,eminObs,emaxObs,e1,e2,ediff,maxAmp, Noise,PkNoise,requireAmp,tooclose)
+                                g.write_QC_fails(delT,delTmax,eminObs,emaxObs,e1,e2,ediff,maxAmp, Noise,PkNoise,requireAmp,tooclose)
 
                             idc = 'f' + stitles[a]
                             data[idc][satNu] = [px,pz]
