@@ -22,7 +22,7 @@ import gnssrefl.cddis_highrate as ch
 
 # fortran codes for translating RINEX
 import gnssrefl.gpssnr as gpssnr
-import gnssrefl.gnsssnr as gnsssnr 
+import gnssrefl.gnsssnr as gnsssnr
 
 import gnssrefl.gnsssnrbigger as gnsssnrbigger
 
@@ -30,14 +30,14 @@ class constants:
     omegaEarth = 7.2921151467E-5 #      %rad/sec
     mu = 3.986005e14 # Earth GM value
     c= 299792458 # m/sec
- 
+
 #
 #
 def quickname(station,year,cyy, cdoy, csnr):
     """
-    finds location/name of a SNR file
+    creates filename for a local SNR file
 
-    Parameters 
+    Parameters
     ----------
     station : str
         station name, 4 character
@@ -45,7 +45,7 @@ def quickname(station,year,cyy, cdoy, csnr):
     year : int
         full year
 
-    cyy : str 
+    cyy : str
         two character year
 
     cdoy : str
@@ -62,31 +62,32 @@ def quickname(station,year,cyy, cdoy, csnr):
     """
     xdir  = os.environ['REFL_CODE'] + '/'
     fname =  xdir + str(year) + '/snr/' + station + '/' + station + cdoy + '0.' + cyy + '.snr' + csnr
+
     return fname
 
 def run_rinex2snr(station, year_list, doy_list, isnr, orbtype, rate,dec_rate,archive,fortran,nol,overwrite,translator,srate,
         mk,skipit,stream,strip):
     """
-    main code to convert RINEX files into SNR
+    main code to convert RINEX files into SNR files that are stored locally
 
     Parameters
     ----------
     station : string
-        4 or 9 character station name 
+        4 or 9 character station name. 6 ch allowed for japanese archive
 
-    year_list : list of int 
+    year_list : list of int
         years to be analyzed
 
     doy_list list of doy to be analyzed
 
-    isnr : integer 
+    isnr : integer
         SNR file type choice
 
     orbtype : string
         3 character orbit type, e.g. nav
-        
-    rate : string 
-        general sample rate. 
+
+    rate : string
+        general sample rate.
         high: use 1-Hz area in the archive
         low: use default area in the archive
 
@@ -96,19 +97,19 @@ def run_rinex2snr(station, year_list, doy_list, isnr, orbtype, rate,dec_rate,arc
     archive : string
         choice of GNSS archive
 
-    fortran : boolean 
+    fortran : boolean
         whether the fortran rinex translator is to be used
         default: false
 
-    nol: boolean 
+    nol: boolean
         True: assumes RINEX files are in local directory
         False (default): will look at multiple - or specific archive
 
     overwrite: boolean
         False (default): if SNR file exists, SNR file not made
-        True: make a new SNR file 
+        True: make a new SNR file
 
-    translator : string 
+    translator : string
         hybrid (default), fortran, or python
         hybrid uses fortran within the python code
 
@@ -118,7 +119,7 @@ def run_rinex2snr(station, year_list, doy_list, isnr, orbtype, rate,dec_rate,arc
     mk : boolean
         makan option
 
-    skipit : boolean
+    skipit : int
          skips making files every day, so a value of 7 means weekly.  1 means do every day
 
     strip : boolean
@@ -126,14 +127,14 @@ def run_rinex2snr(station, year_list, doy_list, isnr, orbtype, rate,dec_rate,arc
          will break the RINEX translator)
 
     """
-    # 
+    #
     # do not allow illegal skipit values
     if skipit < 1:
         skipit = 1
 
     NS = len(station)
     if (NS == 4):
-        #print('Assume RINEX 2.11'); 
+        #print('Assume RINEX 2.11');
         version = 2
         if not mk:
             station = station.lower()
@@ -142,7 +143,7 @@ def run_rinex2snr(station, year_list, doy_list, isnr, orbtype, rate,dec_rate,arc
         if not mk:
             station = station[-4:].upper()
     elif (NS == 9):
-        #print('Assume RINEX 3'); 
+        #print('Assume RINEX 3');
         version = 3
         station9ch = station.upper()
         if not mk:
@@ -150,12 +151,14 @@ def run_rinex2snr(station, year_list, doy_list, isnr, orbtype, rate,dec_rate,arc
     else:
         print('Illegal station input - Station must have 4,6,or 9 characters. Exiting')
         sys.exit()
+
     year_st = year_list[0]
     year_end = year_list[-1]
+
     doy_st = doy_list[0]
     doy_end = doy_list[-1]
 
-# loop thru years and days 
+# loop thru years and days
     for year in year_list:
         ann = g.make_nav_dirs(year)
         cyyyy = str(year)
@@ -200,7 +203,7 @@ def run_rinex2snr(station, year_list, doy_list, isnr, orbtype, rate,dec_rate,arc
                             if strip:
                                 print('Testing out stripping the RINEX 2 file here')
                                 k.strip_rinexfile(r)
-                            conv2snr(year, doy, station, isnr, orbtype,rate,dec_rate,archive,fortran,translator) 
+                            conv2snr(year, doy, station, isnr, orbtype,rate,dec_rate,archive,fortran,translator)
                         else:
                             print('You Chose the No Look Option, but did not provide the needed RINEX file.')
                     if version == 3:
@@ -209,20 +212,23 @@ def run_rinex2snr(station, year_list, doy_list, isnr, orbtype, rate,dec_rate,arc
                         else:
                             csrate = '{:02d}'.format(srate)
                         streamid = '_' + stream  + '_'
-                        # this can be done in a function now ... 
+                        # this can be done in a function now ...
                         r3cmpgz = station9ch + streamid + str(year) + cdoy + '0000_01D_' + csrate + 'S_MO.crx.gz'
                         r3 = station9ch + streamid + str(year) + cdoy + '0000_01D_' + csrate + 'S_MO.rnx'
                         r3gz = station9ch + streamid + str(year) + cdoy + '0000_01D_' + csrate + 'S_MO.rnx.gz'
                         r2 = station + cdoy + '0.' + cyy + 'o'
                         if os.path.exists(r3cmpgz):
-                            translated, rnx_filename = go_from_crxgz_to_rnx(r3cmpgz)
+                            print('Try to translate', r3cmpgz)
+                            deletecrx = True
+                            translated, rnx_filename = go_from_crxgz_to_rnx(r3cmpgz,deletecrx)
                         if os.path.exists(r3gz):
+                            print('Try to gunzip ', r3gz)
                             subprocess.call(['gunzip', r3gz])
                         if os.path.exists(r3):
                             print('The RINEX 3 file exists locally')
                             fexists = g.new_rinex3_rinex2(r3,r2,dec_rate)
                             if fexists:
-                                conv2snr(year, doy, station, isnr, orbtype,rate,dec_rate,archive,fortran,translator) 
+                                conv2snr(year, doy, station, isnr, orbtype,rate,dec_rate,archive,fortran,translator)
                             else:
                                 print('Something about the RINEX 3-2 conversion did not work')
                         else:
@@ -243,7 +249,7 @@ def run_rinex2snr(station, year_list, doy_list, isnr, orbtype, rate,dec_rate,arc
                                 deleteOld = True
                                 # cold should return the new name of the rinex 2 file
                                 r2, foundit = g.ga_highrate(station9ch,year,doy,dec_rate,deleteOld)
-                                if foundit: 
+                                if foundit:
                                     print('rinex2 file should now exist:', r2)
                             if archive == 'cddis':
                                 rnx_filename,foundit = ch.cddis_highrate(station9ch, year, doy, 0,stream,dec_rate)
@@ -268,7 +274,8 @@ def run_rinex2snr(station, year_list, doy_list, isnr, orbtype, rate,dec_rate,arc
                                     #print('stream',stream)
                                     file_name,foundit = k.universal(station9ch, year, doy, archive,srate,k.swapRS(stream))
                             if foundit: # version 3 found - now need to gzip, then hatanaka decompress
-                                translated, rnx_filename = go_from_crxgz_to_rnx(file_name)
+                                deletecrx = True # no point keeping this around
+                                translated, rnx_filename = go_from_crxgz_to_rnx(file_name,deletecrx)
                             # now make rinex2
                                 if translated:
                                     print('The RINEX 3 file has been downloaded. Try to make ', r2)
@@ -278,13 +285,13 @@ def run_rinex2snr(station, year_list, doy_list, isnr, orbtype, rate,dec_rate,arc
                         if fexists:
                              print('RINEX 2 created from v3', year, doy, ' Now remove RINEX 3 files and convert')
                              subprocess.call(['rm', '-f',rnx_filename]) # rnx
-                             conv2snr(year, doy, station, isnr, orbtype,rate,dec_rate,archive,fortran,translator) 
+                             conv2snr(year, doy, station, isnr, orbtype,rate,dec_rate,archive,fortran,translator)
                         else:
                             print('Unsuccessful RINEX 3 retrieval/translation', year, doy)
                     else:
                         print(station, ' year:', year, ' doy:', doy, 'from: ', archive)
                         # this is rinex version 2 - finds rinex and converts it
-                        conv2snr(year, doy, station, isnr, orbtype,rate,dec_rate,archive,fortran,translator) 
+                        conv2snr(year, doy, station, isnr, orbtype,rate,dec_rate,archive,fortran,translator)
 
 
 def conv2snr(year, doy, station, option, orbtype,receiverrate,dec_rate,archive,fortran,translator):
@@ -312,19 +319,19 @@ def conv2snr(year, doy, station, option, orbtype,receiverrate,dec_rate,archive,f
         decimation value to reduce file size
 
     archive : str
-        location of the rinex files
+        external location (archive) of the rinex files
 
     fortran : bool
          whether fortran translator to be used.  this is here for backwards compatability
 
     translator : str
-         hybrid, python, or fortran 
+         hybrid, python, or fortran
 
     """
     # define directory for the conversion executables
     if not os.path.isdir('logs'):
         subprocess.call(['mkdir', 'logs'])
-    logname = 'logs/' + station + '.txt' 
+    logname = 'logs/' + station + '.txt'
     log = open(logname, 'w+')
     log.write("Receiver rate: {0:5s} \n".format(receiverrate))
     log.write("Decimation rate: {0:3.0f} \n".format(dec_rate))
@@ -337,19 +344,19 @@ def conv2snr(year, doy, station, option, orbtype,receiverrate,dec_rate,archive,f
         print("The snrfile already exists: ", snrname_full)
     else:
         log.write("The snrfile does not exist: {0:50s} \n".format(snrname_full))
-        d = g.doy2ymd(year,doy); 
+        d = g.doy2ymd(year,doy);
         month = d.month; day = d.day
         # new function to do the whole orbit thing
-        foundit, f, orbdir, snrexe = g.get_orbits_setexe(year,month,day,orbtype,fortran) 
+        foundit, f, orbdir, snrexe = g.get_orbits_setexe(year,month,day,orbtype,fortran)
         # if you have the orbit file, you can get the rinex file. First lets define the expected names
         print('Orbit file: ', orbdir + '/' + f)
         if foundit:
             # now you can look for a rinex file
             rinexfile,rinexfiled = g.rinex_name(station, year, month, day)
-            # This goes to find the rinex file. I am changing it to allow 
-            # an archive preference 
+            # This goes to find the rinex file. I am changing it to allow
+            # an archive preference
             if receiverrate == 'high':
-                strip_snr = False # for now - 
+                strip_snr = False # for now -
                 file_name, foundit = k.rinex2_highrate(station, year, doy,archive,strip_snr)
             else:
                 # added karnak librariies
@@ -367,11 +374,11 @@ def conv2snr(year, doy, station, option, orbtype,receiverrate,dec_rate,archive,f
 #           define booleans for various files
             oexist = os.path.isfile(orbdir + '/' + f) == True
             rexist = os.path.isfile(rinexfile) == True
-            exc = exedir + '/teqc' 
+            exc = exedir + '/teqc'
             texist = os.path.isfile(exc) == True
-            if rexist: 
+            if rexist:
                 # decimate using teqc  if you have it
-                if (texist) and (fortran) and (dec_rate > 0): 
+                if (texist) and (fortran) and (dec_rate > 0):
                     log.write("Decimating using teqc:  {0:3.0f}  seconds \n".format(dec_rate))
                     log.write('Unfortunately teqc removes Beidou data. Eventually I will remove this. \n')
                     rinexout = rinexfile + '.tmp'; cdec = str(dec_rate)
@@ -440,7 +447,7 @@ def conv2snr(year, doy, station, option, orbtype,receiverrate,dec_rate,archive,f
                 # remove the rinex file
                 subprocess.call(['rm', '-f',rinexfile])
 
-                if os.path.isfile(snrname): 
+                if os.path.isfile(snrname):
 #                make sure it exists and is non-zero size before moving it
                     if (os.stat(snrname).st_size == 0):
                         log.write('you created a zero file size which could mean a lot of things \n')
@@ -450,7 +457,7 @@ def conv2snr(year, doy, station, option, orbtype,receiverrate,dec_rate,archive,f
                         log.write('A SNR file was created: {0:50s}  \n'.format(snrname_full))
                         print('\n')
                         print('SUCCESS: SNR file was created:', snrname_full)
-                        g.store_snrfile(snrname,year,station) 
+                        g.store_snrfile(snrname,year,station)
                 else:
                     print('No SNR file was created - check logs section for additional information')
             else:
@@ -478,9 +485,9 @@ def satorb(week, sec_of_week, ephem):
 
     ephem : ephemeris block
 
-    Returns 
+    Returns
     -------
-    numpy array 
+    numpy array
          the x,y,z, coordinates of the satellite in meters
          and relativity correction (also in meters), so you add, not subtract
 
@@ -538,8 +545,8 @@ def rnx2snr(obsfile, navfile,snrfile,snroption,year,month,day,dec_rate,log):
     navfile : str
         navigation file
 
-    snrfile : str 
-        SNR filename 
+    snrfile : str
+        SNR filename
 
     snroption: integer
         kind of SNR file requested
@@ -550,7 +557,7 @@ def rnx2snr(obsfile, navfile,snrfile,snroption,year,month,day,dec_rate,log):
 
     day : int
 
-    dec_rate : integer 
+    dec_rate : integer
         decimation rate in seconds
 
     """
@@ -570,16 +577,16 @@ def rnx2snr(obsfile, navfile,snrfile,snroption,year,month,day,dec_rate,log):
     exitQ = False
     obsdata, systemsatlists, prntoidx, obstypes, header, obstimes,gpstime = rinpy.processrinexfile(obsfile)
     obsdata = rinpy.separateobservables(obsdata, obstypes)
-    obslist = obstypes['G'][:] 
+    obslist = obstypes['G'][:]
     # need to check to see what happens without coordinates
-    key = 'APPROX POSITION XYZ' 
+    key = 'APPROX POSITION XYZ'
     if key in header.keys():
         log.write('Cartesian coordinates are in the RINEX Header \n')
     else:
         log.write('RINEX file does not have station coordinates. Exiting \n')
         print('RINEX file does not have station coordinates. This is illegal. Exiting')
         return
-    rv =  header['APPROX POSITION XYZ'] 
+    rv =  header['APPROX POSITION XYZ']
     recv = [float(i) for i in rv.split()]
     recv = np.array(recv)
     log.write("XYZ from header {0:15.5f} {1:15.5f} {2:15.5f} \n".format(recv[0],recv[1],recv[2]))
@@ -600,17 +607,17 @@ def rnx2snr(obsfile, navfile,snrfile,snroption,year,month,day,dec_rate,log):
         s2exist = True
     if 'S5' in obslist :
         s5exist = True
-    if not s1exist and not s2exist: 
+    if not s1exist and not s2exist:
         log.write('There are no S1 and no S2 data - this file is not useful for reflectometry \n')
         exitQ = True
     if (orbtype == 'nav'):
-        gpssatlist = systemsatlists['G'][:] 
+        gpssatlist = systemsatlists['G'][:]
         #print('GPS satellite list', gpssatlist)
         navorbits(navfile,obstimes,obsdata,obslist,prntoidx,gpssatlist,snrfile,s1exist,s2exist,s5exist,up,East,North,emin,emax,recv,dec_rate,log)
     else:
         log.write('Read the sp3 file \n'); sp3 = g.read_sp3file(navfile)
-        testing_sp3(gpstime,sp3,systemsatlists,obsdata,obstypes,prntoidx,year,month,day,emin,emax,snrfile,up,East,North,recv,dec_rate,log)
-        #test_sp3(gpstime,sp3,systemsatlists,obsdata,obstypes,prntoidx,year,month,day,emin,emax,snrfile,up,East,North,recv,dec_rate,log)
+        _testing_sp3(gpstime,sp3,systemsatlists,obsdata,obstypes,prntoidx,year,month,day,emin,emax,snrfile,up,East,North,recv,dec_rate,log)
+        #_test_sp3(gpstime,sp3,systemsatlists,obsdata,obstypes,prntoidx,year,month,day,emin,emax,snrfile,up,East,North,recv,dec_rate,log)
 
     #print('Closing python RINEX conversion log file:',logname)
     #log.close()
@@ -619,7 +626,7 @@ def navorbits(navfile,obstimes,observationdata,obslist,prntoidx,gpssatlist,snrfi
     """
     Strandberg nav reading file?
 
-    Parameters 
+    Parameters
     ---------
     navfile : string
 
@@ -627,18 +634,18 @@ def navorbits(navfile,obstimes,observationdata,obslist,prntoidx,gpssatlist,snrfi
 
     observationdata :
 
-    obslist : 
+    obslist :
 
-    prn2oidx : 
+    prn2oidx :
 
     gpssatlist :
 
-    snrfile : str 
+    snrfile : str
         name of the output file
 
     s1exist :
 
-    s2exist : 
+    s2exist :
 
     s5exist :
 
@@ -698,7 +705,7 @@ def readSNRval(s1exist,s2exist,s5exist,observationdata,prntoidx,sat,i):
     what it looks like only reads GPS data for now
     interface between Joakim's code and mine ...
 
-    Parameters 
+    Parameters
     ----------
     s1exist : boolean
 
@@ -706,9 +713,9 @@ def readSNRval(s1exist,s2exist,s5exist,observationdata,prntoidx,sat,i):
 
     s5exist : boolean
 
-    Returns 
+    Returns
     -------
-    s1 : 
+    s1 :
     s2 :
     s5 :
 
@@ -753,7 +760,7 @@ def satorb_prop(week, secweek, prn, rrec0, closest_ephem):
 
     Returns
     -------
-    SatOrbn : 3vector 
+    SatOrbn : 3vector
         floats, Cartesian location of satellite in meters [x,y,z]
 
     """
@@ -790,7 +797,7 @@ def satorb_prop_sp3(iX,iY,iZ,recv,Tp,ij):
     and receiver coordinates rrec0
     find the x,y,z coordinates at time secweek
 
-    Parameters 
+    Parameters
     ----------
     iX : float
 
@@ -799,9 +806,9 @@ def satorb_prop_sp3(iX,iY,iZ,recv,Tp,ij):
     iZ : float
     recv : 3 vector, float
 
-    Tp : 
+    Tp :
 
-    ij : 
+    ij :
 
     sp3 has the orbit information in it
     """
@@ -828,7 +835,7 @@ def satorb_prop_sp3(iX,iY,iZ,recv,Tp,ij):
 
     return SatOrbn
 
-def test_sp3(gpstime,sp3,systemsatlists,obsdata,obstypes,prntoidx,year,month,day, emin,emax,outputfile,up,East,North,recv,dec_rate,log):
+def _test_sp3(gpstime,sp3,systemsatlists,obsdata,obstypes,prntoidx,year,month,day, emin,emax,outputfile,up,East,North,recv,dec_rate,log):
     """
     inputs are gpstime( numpy array with week and sow)
     sp3 is what has been read from the sp3 file
@@ -853,7 +860,7 @@ def test_sp3(gpstime,sp3,systemsatlists,obsdata,obstypes,prntoidx,year,month,day
             satlist = systemsatlists[con][:]
             #print(satlist)
             for prn in satlist:
-                addon = g.findConstell(con) # 100,200,or 300 for R,E, and C 
+                addon = g.findConstell(con) # 100,200,or 300 for R,E, and C
                 log.write('Constellation {0:1s} Satellite {1:2.0f}  Addon {2:3.0f} \n'.format( con, prn, addon))
                 # window out the data for this satellite
                 m = sp3[:,0] == prn + addon
@@ -872,11 +879,11 @@ def test_sp3(gpstime,sp3,systemsatlists,obsdata,obstypes,prntoidx,year,month,day
 
         # indices when there are no data for this satellite
                     ij = np.isnan(s1)
-        # indices when there are data in the RINEX file - this way you do not compute 
+        # indices when there are data in the RINEX file - this way you do not compute
         # orbits unless there are data.
                     not_ij = np.logical_not(ij)
                     Tp = gpstime[not_ij,1] # only use the seconds of the week for now
-                    s1 = s1[not_ij]; 
+                    s1 = s1[not_ij];
                     #print(s1.shape)
                     emp = np.zeros(shape=[len(s1),1],dtype=float)
         # get the rest of the SNR data in a function
@@ -890,16 +897,16 @@ def test_sp3(gpstime,sp3,systemsatlists,obsdata,obstypes,prntoidx,year,month,day
                         if checkD:
                             TT = Tp[ij]  % dec_rate # get the modulus
                         if TT == 0:
-                            SatOrb = satorb_prop_sp3(iX,iY,iZ,recv,Tp,ij) 
+                            SatOrb = satorb_prop_sp3(iX,iY,iZ,recv,Tp,ij)
                             r=np.subtract(SatOrb,recv)
                             azimA = g.azimuth_angle(r, East, North)
                             eleA = g.elev_angle(up, r)*180/np.pi
                             # 2021 october 26
                             # thank you to andrea gatti for pointing out the mistake
                             if (eleA >= emin) and (eleA <= emax):
-                                fout.write("{0:3.0f} {1:10.4f} {2:10.4f} {3:10.0f} {4:7.2f} {5:7.2f} {6:7.2f} {7:7.2f} {8:7.2f} {9:7.2f} {10:7.2f} \n".format( 
+                                fout.write("{0:3.0f} {1:10.4f} {2:10.4f} {3:10.0f} {4:7.2f} {5:7.2f} {6:7.2f} {7:7.2f} {8:7.2f} {9:7.2f} {10:7.2f} \n".format(
                                     prn+addon,eleA,azimA,Tp[ij]-gpssec0, 0,float(s6[ij]),s1[ij],float(s2[ij]),float(s5[ij]),float(s7[ij]),float(s8[ij]) ))
-                                #fout.write("{0:3.0f} {1:10.4f} {2:10.4f} {3:10.0f} {4:7.2f} {5:7.2f} {6:7.2f} {7:7.2f} {8:7.2f} {9:7.2f} {10:7.2f} \n".format( 
+                                #fout.write("{0:3.0f} {1:10.4f} {2:10.4f} {3:10.0f} {4:7.2f} {5:7.2f} {6:7.2f} {7:7.2f} {8:7.2f} {9:7.2f} {10:7.2f} \n".format(
                                 #    prn+addon,eleA,azimA,Tp[ij]-gpssec0, 0,float(s6[ij]),s1[ij],float(s2[ij]),float(s5[ij]),float(s6[ij]),float(s7[ij]) ))
                 else:
                     log.write('This satellite is not in the orbit file. {0:3.0f} \n'.format(prn))
@@ -973,14 +980,8 @@ def elev_limits(snroption):
 
     return emin, emax
 
-def testit(input):
-    """
-    """
-    print(input)
-    return True
 
-
-def testing_sp3(gpstime,sp3,systemsatlists,obsdata,obstypes,prntoidx,year,month,day, emin,emax,outputfile,up,East,North,recv,dec_rate,log):
+def _testing_sp3(gpstime,sp3,systemsatlists,obsdata,obstypes,prntoidx,year,month,day, emin,emax,outputfile,up,East,North,recv,dec_rate,log):
     """
     inputs are gpstime( numpy array with week and sow)
     sp3 is what has been read from the sp3 file
@@ -1011,7 +1012,7 @@ def testing_sp3(gpstime,sp3,systemsatlists,obsdata,obstypes,prntoidx,year,month,
                 satlist = systemsatlists[con][:]
                 for prn in satlist:
                     bar.next()
-                    addon = g.findConstell(con) # 100,200,or 300 for R,E, and C 
+                    addon = g.findConstell(con) # 100,200,or 300 for R,E, and C
                     log.write('Constellation {0:1s} Satellite {1:2.0f}  Addon {2:3.0f} \n'.format( con, prn, addon))
                 # window out the data for this satellite
                     m = sp3[:,0] == prn + addon
@@ -1030,11 +1031,11 @@ def testing_sp3(gpstime,sp3,systemsatlists,obsdata,obstypes,prntoidx,year,month,
 
         # indices when there are no data for this satellite
                         ij = np.isnan(s1)
-        # indices when there are data in the RINEX file - this way you do not compute 
+        # indices when there are data in the RINEX file - this way you do not compute
         # orbits unless there are data.
                         not_ij = np.logical_not(ij)
                         Tp = gpstime[not_ij,1] # only use the seconds of the week for now
-                        s1 = s1[not_ij]; 
+                        s1 = s1[not_ij];
                     #print(s1.shape)
                         emp = np.zeros(shape=[len(s1),1],dtype=float)
         # get the rest of the SNR data in a function
@@ -1047,13 +1048,13 @@ def testing_sp3(gpstime,sp3,systemsatlists,obsdata,obstypes,prntoidx,year,month,
                             if checkD:
                                 TT = Tp[ij]  % dec_rate # get the modulus
                             if TT == 0:
-                                SatOrb = satorb_prop_sp3(iX,iY,iZ,recv,Tp,ij) 
+                                SatOrb = satorb_prop_sp3(iX,iY,iZ,recv,Tp,ij)
                                 r=np.subtract(SatOrb,recv)
                                 azimA = g.azimuth_angle(r, East, North)
                                 eleA = g.elev_angle(up, r)*180/np.pi
                                 if (eleA >= emin) and (eleA <= emax):
                                     # bug reported by Andrea Gatti. 2021 October 26
-                                    fout.write("{0:3.0f} {1:10.4f} {2:10.4f} {3:10.0f} {4:7.2f} {5:7.2f} {6:7.2f} {7:7.2f} {8:7.2f} {9:7.2f} {10:7.2f} \n".format( 
+                                    fout.write("{0:3.0f} {1:10.4f} {2:10.4f} {3:10.0f} {4:7.2f} {5:7.2f} {6:7.2f} {7:7.2f} {8:7.2f} {9:7.2f} {10:7.2f} \n".format(
                                         prn+addon,eleA,azimA,Tp[ij]-gpssec0, 0,float(s6[ij]),s1[ij],float(s2[ij]),float(s5[ij]),float(s7[ij]),float(s8[ij]) ))
                     else:
                         log.write('This satellite is not in the orbit file. {0:3.0f} \n'.format(prn))
@@ -1068,7 +1069,7 @@ def the_makan_option(station,cyyyy,cyy,cdoy):
     this ugly looking code checks a bazillion versions of RINEX versions
     (Z, gz, regular, hatanaka) both in the working directory and in an external rinex area
     $REFL_CODE/rinex/station/year
-    
+
     turns whatever it finds into a regular RINEX file in the working directory
     that file WILL be deleted, but it will not delete those stored externally.
 
@@ -1090,7 +1091,7 @@ def the_makan_option(station,cyyyy,cyy,cdoy):
     print(r,rd)
 
     locdir= os.environ['REFL_CODE'] + '/rinex/' + station + '/' + cyyyy + '/'
-    # 
+    #
     #locdir2= os.environ['RINEX'] + station + '/' + cyyyy + '/'
     #locdir3= os.environ['RINEX'] + station.upper() + '/' + cyyyy + '/'
 
@@ -1124,7 +1125,7 @@ def the_makan_option(station,cyyyy,cyy,cdoy):
             subprocess.call(['rm',rd])
             missing = False
         else:
-            g.hatanaka_warning(); 
+            g.hatanaka_warning();
 
     if os.path.exists(rd + '.Z') and missing:
         subprocess.call(['uncompress', rd + '.Z'])
@@ -1133,7 +1134,7 @@ def the_makan_option(station,cyyyy,cyy,cdoy):
             subprocess.call(['rm',rd])
             missing = False
         else:
-            g.hatanaka_warning() 
+            g.hatanaka_warning()
 
     if os.path.exists(locdir + r) and missing:
         subprocess.call(['cp', '-f',locdir + r,'.'])
@@ -1156,7 +1157,7 @@ def the_makan_option(station,cyyyy,cyy,cdoy):
             subprocess.call(['rm',rd])
             missing = False
         else:
-            g.hatanaka_warning(); 
+            g.hatanaka_warning();
 
     if os.path.exists(locdir + rd + '.Z') and missing:
         subprocess.call(['cp','-f',locdir + rd + '.Z','.'])
@@ -1166,7 +1167,7 @@ def the_makan_option(station,cyyyy,cyy,cdoy):
             subprocess.call(['rm',rd])
             missing = False
         else:
-            g.hatanaka_warning(); 
+            g.hatanaka_warning();
 
     if os.path.exists(locdir + rd + '.gz') and missing:
         subprocess.call(['cp','-f',locdir + rd + '.gz','.'])
@@ -1178,9 +1179,9 @@ def the_makan_option(station,cyyyy,cyy,cdoy):
         else:
             g.hatanaka_warning()
 
-def go_from_crxgz_to_rnx(c3gz):
+def go_from_crxgz_to_rnx(c3gz,deletecrx=True):
     """
-    checks ot see if rinex3 file exists, gunzip if necessary,
+    checks to see if rinex3 file exists, gunzip if necessary,
     run hatanaka, if necessary
 
     Parameters
@@ -1188,6 +1189,9 @@ def go_from_crxgz_to_rnx(c3gz):
     c3gz : str
         filename for a gzipped RINEX 3 Hatanaka file
 
+    deletecrx = bool
+        whether to delete the crx file
+
     Returns
     -------
     translated : bool
@@ -1213,11 +1217,8 @@ def go_from_crxgz_to_rnx(c3gz):
             subprocess.call([crnxpath,c3])
     if os.path.exists(rnx): # file exists
         translated = True
-        #print('remove Hatanaka compressed file')
-        subprocess.call(['rm','-f',c3])
+        if deletecrx:
+            print('remove Hatanaka compressed file')
+            subprocess.call(['rm','-f',c3])
 
     return translated, rnx
-
-
-
-
