@@ -56,6 +56,7 @@ def readklsnrtxt(snrfile, thedir, signal):
     """
     parses the contents of a snrfile f
     the file itself is read in a separate function now, 
+    if SNR data are zero for a given signal, the row is eliminated
 
     Parameters
     ----------
@@ -68,16 +69,13 @@ def readklsnrtxt(snrfile, thedir, signal):
 
     Returns
     -------
-    snrdata : numpy array of floats 
-        columns 
-        0 - satellite, usual (100 added for glonass, 200 added for galileo)
-        1 - elev angle, deg
-        2 - azimuth angle, deg
-        3 - time in seconds since GPS began
-        4 - SNR data in db-Hz
-        5 - new column with wavelength in it, in meters.  might as well take care of that now
-
-    if SNR data are zero for a given signal, the row is eliminated
+    snrdata : numpy array of floats . Columns defined as:
+        0 : satellite, usual (100 added for glonass, 200 added for galileo)
+        1 : elev angle, deg
+        2 : azimuth angle, deg
+        3 : time in seconds since GPS began
+        4 : SNR data in db-Hz
+        5 : new column with wavelength in it, in meters.  
 
     """
     # do a straight load of the file
@@ -269,7 +267,7 @@ def gps2datenum(gt):
     return dn
 
 
-def snr2arcs(snrdata, azilims, elvlims, rhlims, precision, year,doy,signal='L1', normalize=False, 
+def snr2arcs(station,snrdata, azilims, elvlims, rhlims, precision, year,doy,signal='L1', normalize=False, 
         snrfigs=False, lspfigs=False, polydeg=2, gaptlim=5*60, pktnlim=4, 
         savefile=False, screenstats=False, l2c_only=False,satconsts=['G','R','E'], **kwargs):
     """
@@ -278,6 +276,8 @@ def snr2arcs(snrdata, azilims, elvlims, rhlims, precision, year,doy,signal='L1',
 
     Parameters
     ----------
+    station : str
+        4 ch station name
     snrdata: numpy array 
         contents of SNR datafile
 
@@ -418,7 +418,11 @@ def snr2arcs(snrdata, azilims, elvlims, rhlims, precision, year,doy,signal='L1',
     alld = {}
     # initialize values?
     kristine_dictionary(alld,'','')
-    fout = open('my_lsp.txt', 'w+')
+
+    xdir = os.environ['REFL_CODE'] + '/Files/' + station + '/'
+
+    print('invsnr lsp results written to :', xdir + 'my_lsp.txt')
+    fout = open(xdir + 'my_lsp.txt', 'w+')
     for sat in satellite_list:
         # get the data for that satellite
         tfilter = (snrdata[:, 0] == sat)
@@ -803,10 +807,10 @@ def snr2spline(station,year,doy, azilims, elvlims,rhlims, precision, kdt, snrfit
             else:
                 snrdata = np.vstack((snrdata, snrtemp))
 
-    xdir = os.environ['REFL_CODE'] + '/Files/'
-    if not os.path.isdir(xdir):
-        print('make output directory for file')
-        subprocess.call(['mkdir',xdir])
+    # set output directory here
+    g.set_subdir(station)
+    xdir = os.environ['REFL_CODE'] + '/Files/' + station + '/'
+
 
     nr,nc = snrdata.shape
     print('Number of obs', nr, ' number of days', numdays)
@@ -839,7 +843,12 @@ def snr2spline(station,year,doy, azilims, elvlims,rhlims, precision, kdt, snrfit
     # arguments sent directly
     print('Begin Lomb Scargle analysis')
     s1=time.time()
-    rh_arr, snrdt_arr, fspecdict= snr2arcs(snrdata, azilims, elvlims, rhlims, precision, year, doy, signal=signal,**kwargs)
+    rh_arr, snrdt_arr, fspecdict= snr2arcs(station,snrdata, azilims, elvlims, rhlims, precision, year, doy, signal=signal,**kwargs)
+    # should already exist
+    #xdir = os.environ['REFL_CODE'] + '/Files/'
+    #if not os.path.isdir(xdir):
+    #    print('make output directory for file')
+    #    subprocess.call(['mkdir',xdir])
     s2=time.time()
     print('Time spent: ',round(s2-s1,2), ' seconds')
     print(fspecdict)
@@ -982,7 +991,8 @@ def snr2spline(station,year,doy, azilims, elvlims,rhlims, precision, kdt, snrfit
             spl_at_lsp = cubspl_f(Xres)
             ab = rh_arr
 
-            iiout = open('outliers_lsp.txt', 'w+')
+            print('invsnr lsp outliers written to : ', xdir + 'outliers_lsp.txt')
+            iiout = open(xdir + 'outliers_lsp.txt', 'w+')
             for ijk in range(0,len(rh_arr)):
                 dd =  rh_arr[ijk,1]-spl_at_lsp[ijk]
                 if (abs(dd) > outlier_limit):
@@ -1028,7 +1038,7 @@ def snr2spline(station,year,doy, azilims, elvlims,rhlims, precision, kdt, snrfit
         ax.grid(True)
         ax.set_ylabel('RH meters')
         ax.invert_yaxis()
-        spng = str(os.environ['REFL_CODE'])+'/Files/spline_out.png'
+        spng = str(os.environ['REFL_CODE']) + '/Files/' + station + '/' + 'spline_out.png'
         print('Plot with results has been written to ', spng)
         plt.savefig(spng)
         if doplot:
@@ -1615,14 +1625,30 @@ def save_lsp_results(datet,maxind,reflh_sub,sat,elvt,azit,pgram_sub,snrdt,pktn,i
     """
     just cleaning up - move the temp_arr definition to a function
     each column is defined below.
-    inputs are datet (seconds in GPSish time), 
-    reflh_sub (windowed rh?)
-    sat - satellite number
-    elvt - array of elevation angles(deg)
-    azit - array of azimuth angles (deg)
-    snrdt - is detrended SNR data (DC component removed)
-    pktn - peak 2 noise via Dave's definition
-    isignal - frequency, 1,2, or 5
+
+    Parameters
+    ----------
+    datet : float
+        seconds in GPSish time 
+    reflh_sub : numpy of floats?
+        windowed rh estimates
+    sat : int
+        satellite number
+    elvt : numpy array of floats 
+        elevation angles(deg)
+    azit : numpy array of floats
+        azimuth angles (deg)
+    snrdt : numpy array of floats
+        detrended SNR data (DC component removed)
+    pktn : float
+        peak 2 noise via Dave Purnell's definition
+    isignal : int
+        frequency, 1,2, or 5
+
+    Returns
+    -------
+    tmp_arr : numpy array (12 columns)
+
     """
 
     temp_arr = np.empty((1, 12), dtype=object)
@@ -1649,7 +1675,7 @@ def set_refraction_model(station, dmjd,lsp,imodel):
     imodel is 1 for simple refraction model
     eventually will add other refraction models
 
-    Parameter
+    Parameters
     ----------
     station : str
         4 ch station name
@@ -1660,6 +1686,15 @@ def set_refraction_model(station, dmjd,lsp,imodel):
     imodel : integer
         set to 1 (time varying off) or 0 (time varying on)
 
+    Returns
+    -------
+    p : float
+        pressure (units?)
+    T : float
+        temperature in deg C
+    irefr : int
+        number value written to output files to keep track of refraction model
+
     """
     xdir = os.environ['REFL_CODE']
     p = 0; T = 0; irefr = 0
@@ -1675,12 +1710,3 @@ def set_refraction_model(station, dmjd,lsp,imodel):
 
     return p,T,irefr
 
-            #if outfile_type == 'txt':
-            #    txt = True; ioutputfile= xdir + station + '_invsnr.txt'
-            #    iout = open(ioutputfile, 'w+')
-            #    iout.write("{0:s} YYYY MM DD HH MM SS   RH(m) doy  MJD \n".format('#'))
-            #else:
-            #    txt = False; ioutputfile= xdir + station + '_invsnr.csv'
-            #    iout = open(ioutputfile, 'w+')
-            #    iout.write("{0:s} YYYY MM DD HH MM SS   RH(m) doy  MJD \n".format('%'))
-            #print('invsnr output written to: ', ioutputfile)
