@@ -18,13 +18,25 @@ import scipy.interpolate as interpolate
 from scipy.interpolate import interp1d
 import math
 
-def writeout_spline_outliers(tvd_bad):
+def writeout_spline_outliers(tvd_bad,txtdir):
     """
+
+    Write splinefit outliers to a file
+
+    Parameters
+    ----------
+    tvd_bad : numpy array
+        output of the lomb scargle calculations
+
+    txtdir : str
+        location for the output, i.e. $REFL_CODE/FiLes/station
+
     """
     nr,nc=tvd_bad.shape
     if nr > 0:
-        print('Outliers written to: outliers.spline.txt')
-        fout = open('outliers.spline.txt', 'w+')
+        f = txtdir + '/outliers.spline.txt'
+        print('Outliers written to: ', f)
+        fout = open(f, 'w+')
         for w in range(0,nr):
             fout.write('sat {0:3.0f} azim {1:7.2f} delta {2:7.2f} \n'.format( tvd_bad[w,3], tvd_bad[w,5], tvd_bad[w,14]))
         fout.close()
@@ -33,9 +45,13 @@ def writeout_spline_outliers(tvd_bad):
 
 def mirror_plot(tnew,ynew,spl_x,spl_y,txtdir,station,beginT,endT):
     """
-    tnew : numpy of floats
-        time in days of year, with faked data, used for splines
+    Makes a plot of the spline fit to the mirrored RH data
+    Plot is saved to txtdir  as  station_rhdot1.png
 
+    Parameters
+    ----------
+    tnew : numpy of floats
+        time in days of year, including the faked data, used for splines
     ynew : numpy of floats
         RH in meters 
     spl_t : numpy of floats
@@ -52,9 +68,9 @@ def mirror_plot(tnew,ynew,spl_x,spl_y,txtdir,station,beginT,endT):
     """
     fig=plt.figure(figsize=(10,4))
 
-    plt.plot(tnew,ynew, '*', label='obs+fake obs')
+    plt.plot(tnew,ynew, 'b.', label='obs+fake obs')
     i = (spl_x > beginT) & (spl_x < endT) # to avoid wonky points in spline
-    plt.plot(spl_x[i],spl_y[i],'-', label='spline')
+    plt.plot(spl_x[i],spl_y[i],'c-', label='spline')
     plt.title('Mirrored obs and spline fit ')
     plt.legend(loc="upper left")
     plt.ylabel('meters')
@@ -63,8 +79,10 @@ def mirror_plot(tnew,ynew,spl_x,spl_y,txtdir,station,beginT,endT):
     plt.grid()
     g.save_plot(txtdir + '/' + station + '_rhdot1.png')
 
-def print_badpoints(t,outliersize):
+def print_badpoints(t,outliersize,txtdir):
     """
+    prints outliers to a file so you can look at them separately
+
     Parameters
     ----------
     t : numpy array
@@ -75,7 +93,7 @@ def print_badpoints(t,outliersize):
 
     Returns
     -------
-    writes to a file called outliers.txt
+    writes to a file called outliers.txt in the Files/station area
 
     """
 # format of t 
@@ -85,7 +103,7 @@ def print_badpoints(t,outliersize):
 # (0)  (1)   (2) (3)  (4)     (5)   6 )    (7)    (8)   (9)  (10) (11) (12)    (13)     (14)    (15)  (16) ... 
 
     m,n = t.shape
-    f = 'outliers.txt'
+    f = txtdir + '/outliers.txt'
     print('outliers written to file: ', f) 
     fout = open(f, 'w+')
     if (m > 0):
@@ -115,13 +133,10 @@ def output_names(txtdir, txtfile,csvfile,jsonfile):
     -------
     writetxt : bool
         whether output should be plain txt
-
     writecsv : bool
         whether output should be csv format
-
     writejson : bool
         whether output should be json format
-
     outfile : str
         output filename
 
@@ -223,19 +238,19 @@ def write_subdaily(outfile,station,ntv,writecsv,extraline,**kwargs):
                 fout.write(" {0:4.0f},{1:3.0f},{2:7.3f},{3:3.0f},{4:6.3f},{5:6.2f},{6:6.2f},{7:6.2f},{8:6.2f},{9:4.0f},{10:3.0f},{11:2.0f},{12:8.5f},{13:6.2f},{14:7.2f},{15:12.6f},{16:1.0f},{17:2.0f},{18:2.0f},{19:2.0f},{20:2.0f},{21:2.0f} \n".format(year, doy, rh,ntv[i,3],UTCtime,ntv[i,5],ntv[i,6],ntv[i,7],ntv[i,8], ntv[i,9], ntv[i,10],ntv[i,11], ntv[i,12],ntv[i,13], ntv[i,14], ntv[i,15], ntv[i,16],month,day,hour,minute, int(second)))
 
             if extra: 
-                fout.write(" {0:4.0f},{1:3.0f},{2:7.3f},{3:3.0f},{4:6.3f},{5:6.2f},{6:6.2f},{7:6.2f},{8:6.2f},{9:4.0f},{10:3.0f},{11:2.0f},{12:8.5f},{13:6.2f},{14:7.2f},{15:12.6f},{16:1.0f},{17:2.0f},{18:2.0f},{19:2.0f},{20:2.0f},{21:2.0f},{22:7.3f},{23:7.3f} \n".format(year, doy, rh,ntv[i,3],UTCtime,ntv[i,5],ntv[i,6],ntv[i,7],ntv[i,8], ntv[i,9], ntv[i,10],ntv[i,11], ntv[i,12],ntv[i,13], ntv[i,14], ntv[i,15], ntv[i,16],month,day,hour,minute, int(second), newRH[i],RHdot_corr[i]))
+                fout.write(" {0:4.0f},{1:3.0f},{2:7.3f},{3:3.0f},{4:6.3f},{5:6.2f},{6:6.2f},{7:6.2f},{8:6.2f},{9:4.0f},{10:3.0f},{11:2.0f},{12:8.5f},{13:6.2f},{14:7.2f},{15:12.6f},{16:1.0f},{17:2.0f},{18:2.0f},{19:2.0f},{20:2.0f},{21:2.0f},{22:10.3f},{23:10.3f} \n".format(year, doy, rh,ntv[i,3],UTCtime,ntv[i,5],ntv[i,6],ntv[i,7],ntv[i,8], ntv[i,9], ntv[i,10],ntv[i,11], ntv[i,12],ntv[i,13], ntv[i,14], ntv[i,15], ntv[i,16],month,day,hour,minute, int(second), newRH[i],RHdot_corr[i]))
             if write_IF_corrected:
                 print('this option (IF correction) has not been implemented yet for csv files')
 
         else:
             if write_IF_corrected:
-                fout.write(" {0:4.0f} {1:3.0f} {2:7.3f} {3:3.0f} {4:6.3f} {5:6.2f} {6:6.2f} {7:6.2f} {8:6.2f} {9:4.0f} {10:3.0f} {11:2.0f} {12:8.5f} {13:6.2f} {14:7.2f} {15:12.6f} {16:1.0f} {17:2.0f} {18:2.0f} {19:2.0f} {20:2.0f} {21:2.0f} {22:7.3f} {23:7.3f} {24:7.3f} \n".format(year, doy, rh,ntv[i,3], 
+                fout.write(" {0:4.0f} {1:3.0f} {2:7.3f} {3:3.0f} {4:6.3f} {5:6.2f} {6:6.2f} {7:6.2f} {8:6.2f} {9:4.0f} {10:3.0f} {11:2.0f} {12:8.5f} {13:6.2f} {14:7.2f} {15:12.6f} {16:1.0f} {17:2.0f} {18:2.0f} {19:2.0f} {20:2.0f} {21:2.0f} {22:10.3f} {23:10.3f} {24:10.3f} \n".format(year, doy, rh,ntv[i,3], 
                     UTCtime,ntv[i,5],ntv[i,6],ntv[i,7],ntv[i,8], ntv[i,9], ntv[i,10],ntv[i,11], 
                     ntv[i,12],ntv[i,13], ntv[i,14], ntv[i,15], ntv[i,16],month,day, hour,minute, 
                     int(second), ntv[i,22], ntv[i,23], newRH_IF[i] ))
 
             if extra:
-                    fout.write(" {0:4.0f} {1:3.0f} {2:7.3f} {3:3.0f} {4:6.3f} {5:6.2f} {6:6.2f} {7:6.2f} {8:6.2f} {9:4.0f} {10:3.0f} {11:2.0f} {12:8.5f} {13:6.2f} {14:7.2f} {15:12.6f} {16:1.0f} {17:2.0f} {18:2.0f} {19:2.0f} {20:2.0f} {21:2.0f} {22:6.3f} {23:6.3f} \n".format(year, doy, rh, ntv[i,3], 
+                    fout.write(" {0:4.0f} {1:3.0f} {2:7.3f} {3:3.0f} {4:6.3f} {5:6.2f} {6:6.2f} {7:6.2f} {8:6.2f} {9:4.0f} {10:3.0f} {11:2.0f} {12:8.5f} {13:6.2f} {14:7.2f} {15:12.6f} {16:1.0f} {17:2.0f} {18:2.0f} {19:2.0f} {20:2.0f} {21:2.0f} {22:10.3f} {23:10.3f} \n".format(year, doy, rh, ntv[i,3], 
                         UTCtime,ntv[i,5],ntv[i,6],ntv[i,7],ntv[i,8], ntv[i,9], ntv[i,10],ntv[i,11], ntv[i,12],ntv[i,13], ntv[i,14], 
                         ntv[i,15], ntv[i,16],month,day,hour,minute, int(second), newRH[i], RHdot_corr[i]))
 
@@ -438,7 +453,7 @@ def readin_and_plot(station, year,d1,d2,plt2screen,extension,sigma,writecsv,azim
         plt.show()
 
     # this might work... and then again, it might not
-    print_badpoints(tv[ii,:],residuals[ii])
+    print_badpoints(tv[ii,:],residuals[ii],txtdir)
 
     # now write things out - using txtdir variable sent 
     if writecsv: 
@@ -594,17 +609,21 @@ def write_out_header(fout,station,extraline,**kwargs):
     fout.write('% gnssrefl, https://github.com/kristinemlarson \n')
     if len(extraline) > 0:
         fout.write('% IMPORTANT {0:s} \n'.format(  extraline ))
-    fout.write('% Phase Center corrections have NOT been applied \n')
+    fout.write('% Traditional phase center corrections have NOT been applied \n')
     if extra_columns:
-        fout.write("% (1)  (2)   (3) (4)  (5)     (6)   (7)    (8)    (9)   (10)  (11) (12) (13)    (14)     (15)    (16) (17) (18,19,20,21,22) (23)    (24)\n")
-        fout.write("% year, doy, RH, sat,UTCtime, Azim, Amp,  eminO, emaxO,NumbOf,freq,rise,EdotF, PkNoise  DelT     MJD  refr  MM DD HH MM SS  newRH  RHcorr\n")
+        fout.write("% (1)  (2)   (3) (4)  (5)     (6)   (7)    (8)    (9)   (10)  (11) (12) (13)    (14)     (15)    (16) (17) (18,19,20,21,22)    (23)        (24) \n")
+        fout.write("% year, doy, RH, sat,UTCtime, Azim, Amp,  eminO, emaxO,NumbOf,freq,rise,EdotF, PkNoise  DelT     MJD  refr  MM DD HH MM SS   RH with      RHdot \n")
+        fout.write("%             m       hours   deg   v/v    deg   deg                1/-1       ratio    minute        1/0                    RHdotCorr    Corr m    \n")
     else:
         if IFcol:
-            fout.write("% (1)  (2)   (3) (4)  (5)     (6)   (7)    (8)    (9)   (10)  (11) (12) (13)    (14)     (15)    (16) (17) (18,19,20,21,22) (23)    (24)   (25)\n")
-            fout.write("% year, doy, RH, sat,UTCtime, Azim, Amp,  eminO, emaxO,NumbOf,freq,rise,EdotF, PkNoise  DelT     MJD  refr  MM DD HH MM SS  newRH  RHcorr  IFcorr\n")
+            fout.write('% Reflector heights set to the L1-phase center are in column 25 \n')
+            fout.write("% (1)  (2)   (3) (4)  (5)     (6)   (7)    (8)    (9)   (10)  (11) (12) (13)    (14)     (15)    (16) (17) (18,19,20,21,22)   (23)      (24)    (25)\n")
+            fout.write("% year, doy, RH, sat,UTCtime, Azim, Amp,  eminO, emaxO,NumbOf,freq,rise,EdotF, PkNoise  DelT     MJD  refr  MM DD HH MM SS  RH with    RHdot     RH with  \n")
+            fout.write("%             m       hours   deg   v/v    deg   deg                1/-1       ratio    minute        1/0                   RHdotCorr  Corr m    IF Corr  m  \n")
         else:
             fout.write("% (1)  (2)   (3) (4)  (5)     (6)   (7)    (8)    (9)   (10)  (11) (12) (13)    (14)     (15)    (16) (17) (18,19,20,21,22)\n")
             fout.write("% year, doy, RH, sat,UTCtime, Azim, Amp,  eminO, emaxO,NumbOf,freq,rise,EdotF, PkNoise  DelT     MJD  refr  MM DD HH MM SS \n")
+            fout.write("%             m       hours   deg   v/v    deg   deg                1/-1       ratio    minute        1/0                  \n")
 
 
 def writejsonfile(ntv,station, outfile):
@@ -695,8 +714,8 @@ def two_stacked_plots(otimes,tv,station,txtdir,year,d1,d2):
 
     Parameters
     ----------
-    otimes : numpy array
-        datetime
+    otimes : numpy array of datetime objects
+        observations times
 
     tv : numpy array
         gnssrefl results written into this variable using loadtxt
@@ -791,14 +810,14 @@ def stack_two_more(otimes,tv,ii,jj,stats, station, txtdir, sigma,kplt):
 
     Parameters
     ----------
-    otimes - numpy array of datetime objects ?
+    otimes : numpy array of datetime objects 
         observation times
 
-    tv - variable with the gnssrefl results
+    tv : variable with the gnssrefl results
 
-    ii - good data?
+    ii : good data?
 
-    jj - bad data?
+    jj : bad data?
 
     station : string
         station name
@@ -980,7 +999,7 @@ def rhdot_plots(th,correction,rhdot_at_th, tvel,yvel,fs,station,txtdir):
     """
     fig=plt.figure(figsize=(10,6))
     plt.subplot(2,1,1)
-    plt.plot(th, correction,'.')
+    plt.plot(th, correction,'b.')
     plt.ylabel('meters',fontsize=fs);
     plt.xlim((np.min(th), np.max(th)))
     plt.grid()
@@ -990,8 +1009,8 @@ def rhdot_plots(th,correction,rhdot_at_th, tvel,yvel,fs,station,txtdir):
     plt.subplot(2,1,2)
     A1 = np.min(th) ; A2 = np.max(th)
     jj = (tvel >= A1) & (tvel <= A2)
-    plt.plot(th, rhdot_at_th,'o',label='at GNSS obs')
-    plt.plot(tvel[jj], yvel[jj],'-', label='spline fit')
+    plt.plot(th, rhdot_at_th,'bo',label='at GNSS obs')
+    plt.plot(tvel[jj], yvel[jj],'c-', label='spline fit')
     plt.legend(loc="upper left")
     plt.grid()
     plt.title('surface velocity')
@@ -1098,6 +1117,9 @@ def flipit(tvd,col):
     ynew = ynew[ii]
 
     # this is what should be used for the spline.
+    #plt.figure()
+    #plt.plot(tnew,ynew,'.')
+    #plt.show()
     return tnew, ynew
 
 
@@ -1133,7 +1155,20 @@ def rhdot_correction2(station,fname,fname_new,pltit,outlierV,**kwargs):
         txtdir = xdir + '/Files/'
     else:
         txtdir = val
-    print('output directory: ', txtdir)
+
+    delta_out = kwargs.get('delta_out',0)
+    if (delta_out  == 0):
+        splineout = False
+    else:
+        splineout = True
+
+    if_corr = kwargs.get('if_corr',True)
+    if if_corr:
+        apply_corr = True
+    else:
+        apply_corr = False
+
+    #print('output directory: ', txtdir)
 
 #   how often do you want velocity computed (per day)
     perday = 24*20 # so every 3 minutes
@@ -1232,7 +1267,7 @@ def rhdot_correction2(station,fname,fname_new,pltit,outlierV,**kwargs):
 
     plt.plot(th, h, 'b.', label=label1,markersize=4)
     iw = (spl_x > th[0]) & (spl_x < th[-1])
-    plt.plot(spl_x[iw], spl_y[iw], 'r--', label='spline') # otherwise wonky spline makes a goofy plot
+    plt.plot(spl_x[iw], spl_y[iw], 'c--', label='spline') # otherwise wonky spline makes a goofy plot
 
     plt.plot(th,correctedRH,'m.',label=label2,markersize=4)
 
@@ -1250,11 +1285,11 @@ def rhdot_correction2(station,fname,fname_new,pltit,outlierV,**kwargs):
 
 
     plt.subplot(2,1,2)
-    plt.plot(th, residual_after,'.',label='all pts')
+    plt.plot(th, residual_after,'r.',label='all pts')
 
 
     tvd_bad = tvd[np.abs(residual_after) >  3*sigmaAfter, :]
-    writeout_spline_outliers(tvd_bad)
+    writeout_spline_outliers(tvd_bad,txtdir)
 
     # keep values within 3 sigma 
     ii = np.abs(residual_after) < 3*sigmaAfter
@@ -1263,7 +1298,7 @@ def rhdot_correction2(station,fname,fname_new,pltit,outlierV,**kwargs):
     correctedRH_new = correctedRH[ii]
     NV = len(correctedRH)
 
-    plt.plot(th[ii], residual_after[ii],'.',label='kept pts')
+    plt.plot(th[ii], residual_after[ii],'b.',label='kept pts')
     plt.grid()
     plt.title('Residuals to the spline fit')
     plt.xlabel('days of the year')
@@ -1287,6 +1322,7 @@ def rhdot_correction2(station,fname,fname_new,pltit,outlierV,**kwargs):
     print('Percent of observations removed:', round(100*(NV-nr)/NV,2))
 
     # now make yet another vector - this time to apply bias corrections
+    # this is horrible code and needs to be fixed
     biasCorrected_RH = correctedRH_new
 
     print('Check inter-frequency biases for GPS, Glonass, and Galileo\n')
@@ -1298,9 +1334,17 @@ def rhdot_correction2(station,fname,fname_new,pltit,outlierV,**kwargs):
         print('Biases will be computed with respect to L1 GPS')
         L1exist = True
 
+    tvd_new = np.loadtxt(fname_new,comments='%')
+    nr,nc = tvd_new.shape
+    onecol = np.zeros((nr,1)) # 
+
+    # add a column for the IF correction
+    tvd_new = np.hstack((tvd_new,onecol))
+    nr,nc = tvd_new.shape
+
     print('Freq  Bias  Sigma   NumObs ')
     print('       (m)   (m)       ')
-    for f in [1, 2, 20, 5, 101, 102, 201, 205,207,208]:
+    for f in [1, 2, 20, 5, 20, 101, 102, 201, 205,206,207,208,302,306,307]:
         ff = (tvd_new[:,10] == f)
         ret = residual_after[ff]
         if len(ret) > 0:
@@ -1310,25 +1354,27 @@ def rhdot_correction2(station,fname,fname_new,pltit,outlierV,**kwargs):
             if L1exist: # apply L1bias so that everything is relative to L1
                 bias = bias - L1bias
 
-            biasCorrected_RH[ff] = biasCorrected_RH[ff] - bias 
+            tvd_new[ff,24] = tvd_new[ff,22] - bias
+
+            # print stats to the screen
             sig = float(np.std(ret))
             print('{0:3.0f} {1:7.3f} {2:7.3f} {3:6.0f}'.format (f, bias, sig, len(ret) ) )
 
 
-    tvd = np.loadtxt(fname_new,comments='%')
-
     # now try to write the bias corrected values
-    bias_corrected_filename = fname_new + 'IF'; extraline = ''; writecsv = False
-    write_subdaily(bias_corrected_filename,station,tvd, writecsv,extraline, newRH_IF=biasCorrected_RH)
+    # first attempt was wrong because i forgot to sort the corrected column in biasCorrected_RH
+    #bias_corrected_filename = fname_new + 'IF'; extraline = ''; writecsv = False
+    biasCor_rh = tvd_new[:,24]
+    #write_subdaily(bias_corrected_filename,station,tvd_new, writecsv,extraline, newRH_IF=biasCor_rh)
 
+    #tvd = np.loadtxt(bias_corrected_filename,comments='%')
+    #tvd = tvd_new 
     # now use the bias corrected value
-    th = tvd[:,1] + tvd[:,4]/24 # days of year, fractional
-    tvd[:,22] = biasCorrected_RH # save this here because flipit will expect it
-    h = biasCorrected_RH
-
+    th = tvd_new[:,1] + tvd_new[:,4]/24 # days of year, fractional
+ 
     # add mirror time series at beginning and end of series for spline
-    column = 23 # tells the code which column to use. 
-    tnew, ynew = flipit(tvd,column)
+    column = 25 # tells the code which column to use. 
+    tnew, ynew = flipit(tvd_new,column)
 
     Ndays = tnew.max()-tnew.min()
     numKnots = int(knots_per_day*(Ndays))
@@ -1342,41 +1388,81 @@ def rhdot_correction2(station,fname,fname_new,pltit,outlierV,**kwargs):
     t, c, k = interpolate.splrep(tnew, ynew, s=0, k=3,t=knots,task=-1)
     # compute spline - use for times th
     spline = interpolate.BSpline(t, c, k, extrapolate=False)
+
+
+    # calculate spline values at GPS time tags
     spline_at_GPS = spline(th)
     half_hourly = int(48*(th[-1] - th[0]))
+    # evenly spaced spline values
     th_even = np.linspace(th[0], th[-1],half_hourly );
     spline_whole_time = spline(th_even)
 
-    newsigma = np.std(h-spline_at_GPS)
+    newsigma = np.std(biasCor_rh-spline_at_GPS)
     strsig = str(round(newsigma,3)) + '(m)'
 
-    # this is last plot -the one with new spline
-
     fig=plt.figure(figsize=(10,6))
     plt.subplot(2,1,1)
-    plt.plot(th, h, '.', label='RH with RHdot/IFcorr ' + strsig)
-    plt.plot(th_even, spline_whole_time, '-',label='newspline')
+    plt.plot(th, biasCor_rh, 'b.', label='RH with RHdot/IFcorr ' + strsig)
+    plt.plot(th_even, spline_whole_time, 'c-',label='newspline')
+
+    # identify 3 sigma outliers
+    ii = np.abs(biasCor_rh -spline_at_GPS)/newsigma > 3
+    # points to keep
+    jj = np.abs(biasCor_rh -spline_at_GPS)/newsigma < 3
+
+    plt.plot(th[ii], biasCor_rh[ii], 'rx', label='3-sig outliers' + strsig)
+
     plt.legend(loc="upper left")
     plt.grid()
     plt.gca().invert_yaxis()
     plt.ylabel('meters')
-    plt.title('New spline with RHdot corr/IF biases/initial 3sigma outliers removed')
+    plt.title('New spline with RHdot corr/InterFreq corr/initial 3sigma outliers removed')
 
     plt.subplot(2,1,2)
-    plt.plot(th, h-spline_at_GPS, '.',label='all residuals')
+    plt.plot(th, biasCor_rh - spline_at_GPS, 'b.',label='all residuals')
     plt.title('Residuals to new spline fit')
     plt.grid()
     plt.ylabel('meters')
     plt.xlabel('days of the year')
 
-    # identify 3 sigma outliers
-    ii = np.abs(h-spline_at_GPS)/newsigma > 3
-    plt.plot(th[ii], (h-spline_at_GPS)[ii], '.',label='3 sigma')
+    plt.plot(th[ii], (biasCor_rh -spline_at_GPS)[ii], 'r.',label='3-sig')
     plt.legend(loc="upper left")
+
     print('RMS with frequency bias taken out (m) ', np.round(newsigma,3)  )
     g.save_plot(txtdir + '/' + station + '_rhdot4.png')
 
-    # was looking at issue of delT being too big
+    # bias corrected - and again without 3 sigma outliers
+    bias_corrected_filename = fname_new + 'IF'; extraline = ''; writecsv = False
+    biasCor_rh = tvd_new[jj,24]
+    write_subdaily(bias_corrected_filename,station,tvd_new[jj,:], writecsv,extraline, newRH_IF=biasCor_rh)
+
+    # I was looking at issue of delT being too big
+
+    if splineout:
+        if delta_out == 0:
+            print('no spline values are written')
+        else:
+            #
+            iyear = int(tvd_new[0,0])
+            firstpoint  = th[0]; lastpoint = th[-1]
+            s1 = math.floor(firstpoint) ; s2 = math.ceil(lastpoint)
+            ndays = s2-s1 # number of days
+            # how many values you want in the linspace world
+            numvals = 1 + int(ndays*86400/delta_out)
+            # this should be fractional doy
+            tplot = np.linspace(s1, s2, numvals)
+            spline_even = spline(tplot)
+            N = len(tplot)
+            # but you only want those values when we have data ....
+            splinefileout =  txtdir + '/' + station + '_spline_out.txt'
+            print('Writing evenly sampled file to: ', splinefileout)
+            fout = open(splinefileout,'w+')
+            for i in range(0,N):
+                modjul = g.fdoy2mjd(iyear,tplot[i])
+                if (tplot[i] > firstpoint) & (tplot[i] < lastpoint):
+                    fout.write('{0:15.7f}  {1:10.3f} \n'.format(modjul, spline_even[i]))
+            fout.close()
+
     if  False:
         plt.figure()
         res = (h-spline_at_GPS)
